Enum purp_value::value::Value

source ·
pub enum Value {
    String(StringB),
    Number(Number),
    Boolean(bool),
    Array(Array),
    Object(Object),
    Null,
    Undefined,
    DateTime(DateTime),
}
Represents different data types as an enum.

Variants



String(StringB)



Number(Number)



Boolean(bool)



Array(Array)



Object(Object)



Null



Undefined



DateTime(DateTime)

Implementations

source

impl Value

source

pub fn to_json(&self, mode: JsonMode) -> String

Converts a Value into a JSON string.

Arguments
  • mode - A JsonMode value representing the JSON output format mode.
Examples
use json_utils::{Value, JsonMode};

let value = Value::str_to_value("{\"name\":\"John Doe\",\"age\":30,\"is_active\":true}").unwrap();
let json_string = value.to_json(JsonMode::Indented);
println!("{}", json_string);
source

impl Value

source

pub fn to_yaml_with_indent(&self, indent: usize) -> String

Returns the YAML representation of the given Value with the specified indentation.

Arguments
  • indent - The number of spaces to use for indentation.
Example
let value = Value::from(vec![Value::from(1), Value::from(2), Value::from(3)]);
assert_eq!(value.to_yaml_with_indent(2), " - 1\n   - 2\n   - 3\n".to_string());
source

pub fn to_yaml(&self) -> String

Returns the YAML representation of the given Value.

Example
let value = Value::from(vec![Value::from(1), Value::from(2), Value::from(3)]);
assert_eq!(value.to_yaml(), "- 1\n  - 2\n  - 3\n".to_string());
source

impl Value

source

pub fn str_to_value(str: &str) -> Result<Value, Error>

Parses a string to a Value.

Arguments
  • str - A string slice to parse.
Errors

Returns an Error if the string is not parseable.