Trait purp_value::value::TypeToValue
source · pub trait TypeToValue {
// Required method
fn to_value(&self) -> Value;
}Expand description
A trait to convert a data type to a Value enum.
pub trait TypeToValue {
// Required method
fn to_value(&self) -> Value;
}A trait to convert a data type to a Value enum.